---
title: <span class="badge object-type-scalar"></span> BoolYesNo
---
# <span class="badge object-type-scalar"></span> BoolYesNo

Boolean: Yes / No

## Definition

```python
# Boolean: Yes / No
BoolYesNo: typing.Literal["bool_yes_no"] = "bool_yes_no"
```
